@@ -19,6 +19,8 @@ from ..decode.extractors import ResourceExtractor
 from ..decode.extractors import ResourcePropertyExtractor
 from ..ref import REF_EXTRACTOR
 from ..ref import REF_SRC_EXTRACTOR
+from .cursor import text_edit
+from .cursor import word_before_after_position
 from .functions import intrinsic_function_completions
 from .resources import resource_completions
 
@@ -34,12 +36,12 @@ def completions_for(
     resource_lookup = ResourceExtractor().extract(template_data)
     res_span = resource_lookup.at(line, char)
     if res_span:
-        return resource_completions(res_span.value, aws_context, document, line)
+        return resource_completions(res_span.value, aws_context, document, position)
     prop_lookup = ResourcePropertyExtractor().extract(template_data)
     prop_span = prop_lookup.at(line, char)
     if prop_span:
         return property_completions(prop_span.value, aws_context, document, position)
-    ref_completions_result = ref_completions(template_data, position)
+    ref_completions_result = ref_completions(template_data, document, position)
     if ref_completions_result:
         return ref_completions_result
     return intrinsic_function_completions(document, position)
@@ -51,24 +53,32 @@ def property_completions(
     document: Document,
     position: Position,
 ) -> CompletionList:
-    add_colon = not re.match(
-        r".*:.*", document.lines[position.line]
-    ) and not document.filename.endswith("json")
-    return CompletionList(
-        is_incomplete=False,
-        items=[
-            CompletionItem(
-                label=s,
-                documentation=aws_context.description(name.parent / s),
-                insert_text=s + (": " if add_colon else ""),
-            )
-            for s in aws_context.same_level(name)
-        ],
-    )
+    if name.parent in aws_context:
+        before, after = word_before_after_position(document.lines, position)
+        suffix = (
+            ": "
+            if not re.match(r".*:.*", document.lines[position.line])
+            and not document.filename.endswith("json")
+            else ""
+        )
+        return CompletionList(
+            is_incomplete=False,
+            items=[
+                CompletionItem(
+                    label=s,
+                    documentation=aws_context.description(name.parent / s),
+                    text_edit=text_edit(position, before, after, s + suffix),
+                )
+                for s in aws_context.same_level(name)
+            ],
+        )
+    else:
+        return CompletionList(is_incomplete=False, items=[])
 
 
 def ref_completions(
     template_data: Tree,
+    document: Document,
     position: Position,
     ref_extractor: Extractor[AWSRefName] = REF_EXTRACTOR,
     ref_src_extractor: Extractor[AWSRefSource] = REF_SRC_EXTRACTOR,
@@ -76,11 +86,13 @@ def ref_completions(
     ref_lookup = ref_extractor.extract(template_data)
     ref_span = ref_lookup.at(position.line, position.character)
     if ref_span:
+        before, after = word_before_after_position(document.lines, position)
         ref_src_lookup = ref_src_extractor.extract(template_data)
         items = [
             CompletionItem(
                 label=ref_src.logical_name,
                 documentation=ref_src.as_documentation(),
+                text_edit=text_edit(position, before, after, ref_src.logical_name),
             )
             for ref_src, _ in ref_src_lookup.items()
         ]
